# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Changed

- Update README (#15)

## [0.0.3] - 2019-11-02

### Changed

- Use GitHub CLI for release

## [0.0.2] - 2019-11-01

### Changed

- Transfer to EnergySage

## [0.0.1] - 2019-10-22

### Changed

- Tweak contributing guidelines

## [0.0.0] - 2019-10-21

### Added

- Initial project structure, tooling, and contributing guidelines

[Unreleased]: https://github.com/energysage/pytest-quarantine/compare/0.0.3...HEAD
[0.0.3]: https://github.com/energysage/pytest-quarantine/releases/tag/0.0.3
[0.0.2]: https://github.com/energysage/pytest-quarantine/releases/tag/0.0.2
[0.0.1]: https://github.com/energysage/pytest-quarantine/releases/tag/0.0.1
[0.0.0]: https://github.com/energysage/pytest-quarantine/releases/tag/0.0.0
